Security Advisories (9)
CPANSA-Mojolicious-2022-03 (2022-12-10)

Mojo::DOM did not correctly parse <script> tags.

CPANSA-Mojolicious-2021-02 (2021-06-01)

Small sessions could be used as part of a brute-force attack to decode the session secret.

CVE-2021-47208 (2021-03-16)

A bug in format detection can potentially be exploited for a DoS attack.

CVE-2018-25100 (2018-02-13)

Mojo::UserAgent::CookieJar leaks old cookies because of the missing host_only flag on empty domain.

CPANSA-Mojolicious-2015-01 (2015-02-02)

Directory traversal on Windows

CPANSA-Mojolicious-2018-03 (2018-05-19)

Mojo::UserAgent was not checking peer SSL certificates by default.

CVE-2020-36829 (2020-11-10)

Mojo::Util secure_compare can leak the string length. By immediately returning when the two strings are not the same length, the function allows an attacker to guess the length of the secret string using timing attacks.

CPANSA-Mojolicious-2018-02 (2018-05-11)

GET requests with embedded backslashes can be used to access local files on Windows hosts

CVE-2024-58134 (2025-05-03)

Mojolicious versions from 0.999922 for Perl uses a hard coded string, or the application's class name, as a HMAC session secret by default. These predictable default secrets can be exploited to forge session cookies. An attacker who knows or guesses the secret could compute valid HMAC signatures for the session cookie, allowing them to tamper with or hijack another user's session.

NAME

Mojo::Server - HTTP server base class

SYNOPSIS

package Mojo::Server::MyServer;
use Mojo::Base 'Mojo::Server';

sub run {
  my $self = shift;

  # Get a transaction
  my $tx = $self->build_tx;

  # Emit "request" event
  $self->emit(request => $tx);
}

DESCRIPTION

Mojo::Server is an abstract HTTP server base class.

EVENTS

Mojo::Server inherits all events from Mojo::EventEmitter and can emit the following new ones.

request

$server->on(request => sub {
  my ($server, $tx) = @_;
  ...
});

Emitted when a request is ready and needs to be handled.

$server->unsubscribe('request');
$server->on(request => sub {
  my ($server, $tx) = @_;
  $tx->res->code(200);
  $tx->res->headers->content_type('text/plain');
  $tx->res->body('Hello World!');
  $tx->resume;
});

ATTRIBUTES

Mojo::Server implements the following attributes.

app

my $app = $server->app;
$server = $server->app(MojoSubclass->new);

Application this server handles, defaults to a Mojo::HelloWorld object.

group

my $group = $server->group;
$server   = $server->group('users');

Group for server process.

reverse_proxy

my $bool = $server->reverse_proxy;
$server  = $server->reverse_proxy($bool);

This server operates behind a reverse proxy, defaults to the value of the MOJO_REVERSE_PROXY environment variable.

user

my $user = $server->user;
$server  = $server->user('web');

User for the server process.

METHODS

Mojo::Server inherits all methods from Mojo::EventEmitter and implements the following new ones.

build_app

my $app = $server->build_app('Mojo::HelloWorld');

Build application from class.

build_tx

my $tx = $server->build_tx;

Let application build a transaction.

daemonize

$server->daemonize;

Daemonize server process.

load_app

my $app = $server->load_app('/home/sri/myapp.pl');

Load application from script.

say Mojo::Server->new->load_app('./myapp.pl')->home;

new

my $server = Mojo::Server->new;

Construct a new Mojo::Server object and subscribe to "request" event with default request handling.

run

$server->run;

Run server. Meant to be overloaded in a subclass.

setuidgid

$server = $server->setuidgid;

Set "user" and "group" for process.

SEE ALSO

Mojolicious, Mojolicious::Guides, http://mojolicio.us.